"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts_morph_1 = require("ts-morph");
const project = new ts_morph_1.Project();
const formatterTags = (jsDocsTags) => {
    const tags = {};
    jsDocsTags.forEach((tag) => {
        const tagName = tag.getTagName();
        tags[tagName] = [
            {
                title: tagName,
                description: tag.getCommentText(),
            },
        ];
    });
    return tags;
};
const formatterProps = (properties) => {
    const props = [];
    properties.forEach((p) => {
        var _a;
        const jsDocs = p.getJsDocs()[0];
        if (!jsDocs) {
            return;
        }
        props.push({
            name: p.getName(),
            type: {
                name: ((_a = p.getTypeNode()) === null || _a === void 0 ? void 0 : _a.getText()) || '',
            },
            description: jsDocs.getDescription(),
            tags: formatterTags(jsDocs.getTags()),
        });
    });
    return props;
};
exports.default = (filePath) => {
    project.addSourceFileAtPath(filePath);
    const sourceFile = project.getSourceFile(filePath);
    const componentDocList = [];
    if (sourceFile) {
        const interfaces = sourceFile.getInterfaces();
        interfaces.forEach((interfaceDeclaration) => {
            const properties = interfaceDeclaration.getProperties();
            const componentDoc = {
                displayName: interfaceDeclaration.getName(),
                exportName: interfaceDeclaration.getName(),
                props: formatterProps(properties),
                // todo: 后续调整
                tags: {}
            };
            if (componentDoc.props.length) {
                componentDocList.push(componentDoc);
            }
        });
    }
    return componentDocList;
};
//# sourceMappingURL=parse-interface.js.map